### Name: XReg
### Title: Extreme Regression
### Aliases: XReg
### Keywords: regression nonlinear

### ** Examples

##
  

# Simple MAX-MIN  example

ffsimp=function(x) {
        eta=pmax(pmin(1*x[,1],.5*x[,2]),pmin(x[,3],x[,4]))
        return(eta) }

# training data
set.seed(123)
n=500
x=matrix(rnorm(n*5),ncol=5)
eta=ffsimp(x)
y=eta+rnorm(n)*1

# For survival data would need to load SURVIVAL library

# XR regression
# specify form of model. 
varlist=list(c(1,2),c(3,4))
outxr1=XReg(y,x,varlist,step.size=.5,niter=20) 

# XR regression using adaptive step-size

outxr2=XReg(y,x,varlist,step.size=.5,step.adapt=TRUE,niter=20) 

# ----------------------------------------------------------------------------
# XR Survival analysis

# load packages
library(survival)  
library(splines)

# MAKE SURVIVAL DATA
tt=-log(runif(n))/exp(eta-mean(eta))  # make uncensored survival times
cc=runif(n)*4   # make censoring times

status=1*(tt<cc)
times=status*tt+(1-status)*cc                 

# Exponential extreme regression model

outxr4=XReg(y,x,varlist,step.size=.5,step.adapt=FALSE,niter=20,survival=TRUE,times=times,status=status) 

#------------------------------------------------------------------------------------
# Find the rule correspondint to a cutpoint eta=0

ooo=level.set(0,outxr1,pred=TRUE,xpred=x)

print(ooo$cutpoints)
#----------------------------------------------------------------------------------
# EXAMPLES OF PLOTTING FUNCTIONS
# Plot the regression function

plotXRreg(y,x,outxr1,allpoints=FALSE) # only show active points
plotXRreg(y,x,outxr1,allpoints=TRUE) # show all data points

# Plot the inverse regression function

plotXRinvreg(x,outxr1,shading=TRUE,quant=TRUE) # plot against quantiles
# Plot against regression function (but put quantiles on upper horizontal axis
plotXRinvreg(x,outxr1,shading=TRUE,quant=FALSE,both=TRUE,qlev=(1:9)/10)  

#----------------------------------------------------------------------------------
# STEPWISE BUIDING FOR XR MODEL 
# this example builds models on martingale residuals

outstepxr1=stepXR(y,x,ypred=y,xpred=x,niterfull=10,niter=5,step.size=.3,kstep=8,kbest=4,penalty=3,survival=FALSE)

# pick model with best GCV
varlist=outstepxr1$steplist[[outstepxr1$bestgcv]]
# fit final model with larger number of interations.
outxrs=XReg(y=y,x=x,varlist=varlist,step.adapt=TRUE,niter=20,limsize=.05,step.size=.5,
             survival=FALSE)

# Get predicted values from the model 
etaxr=predictfun(xpred=x,varlist=varlist,outxrs$beta0list)$predicted

# get rules for upper 90
levelout=level.set(quantile(etaxr,.90),outxrs,pred=TRUE,xpred=x)
print(levelout$cutpoints)

# These are the observations corresponding to that group
group=levelout$selectobs



